# Remind
Terminal reminder tool
## Install:
* `git clone https://github.com/SomethingGeneric/Remind`
* `cd Remind && pip3 install .`
* You need to make sure that `~/.local/bin/` is in your `$PATH`. 
    * This is usually set by `.bashrc` or `.zshrc` depending on your shell.
    * You can check by issuing `echo $PATH`, and looking for that entry between `:`'s.
* Done!
## Usage:
See `remind/main.py` (or `remind help` once it's installed)
